@@ -148,9 +148,12 @@ EAction.prototype.finishEvent = function() {
     // reset CAD tool bar:
     if (!isNull(guiAction) && guiAction.getGroup() === "") {
         var appWin = EAction.getMainWindow();
-        var cadToolBar = appWin.findChild("CadToolBar");
-        if (!isNull(cadToolBar) && cadToolBar.getCurrentPanelName()==="SnapToolsPanel") {
-            cadToolBar.back();
+        if (!isNull(appWin)) {
+            // appWin can be NULL if it is being deleted
+            var cadToolBar = appWin.findChild("CadToolBar");
+            if (!isNull(cadToolBar) && cadToolBar.getCurrentPanelName()==="SnapToolsPanel") {
+                cadToolBar.back();
+            }
         }
     }
 
@@ -237,6 +240,10 @@ EAction.prototype.setState = function(state) {
     }
 };
 
+EAction.prototype.getState = function() {
+    return this.state;
+};
+
 /**
  * Called to initialize a new state of this action. Overwrite to
  * set mouse tips, show desired toolbars, etc.
@@ -379,9 +386,9 @@ EAction.prototype.showUiOptions = function(resume, restoreFromSettings) {
 
         // show:
         this.settingsGroup = wOptions.objectName;
-        this.optionWidgetActions = this.optionWidgetActions
-                .concat(WidgetFactory.moveChildren(wOptions, optionsToolBar,
-                        this.settingsGroup));
+        var movedWidgets = WidgetFactory.moveChildren(wOptions, optionsToolBar, this.settingsGroup);
+
+        this.optionWidgetActions = this.optionWidgetActions.concat(movedWidgets);
 
         // required for undocked options tool bar:
         if (optionsToolBar.floating) {
@@ -396,11 +403,16 @@ EAction.prototype.showUiOptions = function(resume, restoreFromSettings) {
 
         // give action a chance to initialize toolbar widgets that cannot
         // be initialized in Qt Designer:
-        this.initUiOptions(resume, optionsToolBar);
+        if (i===this.uiFile.length-1) {
+            this.initUiOptions(resume, optionsToolBar);
+        }
 
         // restore previously stored state:
         if (restoreFromSettings===true) {
+            // make sure auto focus widgets are not activated while restoring:
+            optionsToolBar.setProperty("Restoring", true);
             WidgetFactory.restoreState(optionsToolBar, this.settingsGroup, this);
+            optionsToolBar.setProperty("Restoring", false);
         }
     }
 
@@ -414,37 +426,15 @@ EAction.prototype.showUiOptions = function(resume, restoreFromSettings) {
  * Overwrite to initialize combo boxes and other UI elements of the options tool
  * bar.
  */
-EAction.prototype.initUiOptions = function(resume, optionsToolBar) {
-    var prefixChar = RSettings.getStringValue("ToolBar/PrefixChar", ",");
-
+EAction.prototype.initUiOptions = function(resume, optionsToolBar, forDialog) {
     if (isNull(optionsToolBar)) {
         return;
     }
-
-    var children = optionsToolBar.children();
-    for (var i=0; i<children.length; i++) {
-        var child = children[i];
-        if (isNull(child)) {
-            continue;
-        }
-
-        var shortCut = child.shortcut;
-        if (!isNull(shortCut) && !shortCut.isEmpty()) {
-            var str = shortCut.toString();
-            var firstChar = str[0];
-
-            // if first key is Ctrl then the string starts with Ctrl+
-            // so check for a + sign, which indicates a modifier key has been used
-            // '+' and '-' should not be used as prefix, as they zoom in and out
-            if (str.indexOf('+') === -1) {                       // no plus sign
-                if (firstChar >= '!' && firstChar <= '~') {      // isgraph()
-                    str = str.replace(firstChar, prefixChar);
-                    child.shortcut = new QKeySequence(str);
-                    child.toolTip = RGuiAction.formatToolTip(child.toolTip, str);
-                }
-            }
-        }
+    if (isNull(forDialog)) {
+        forDialog = false;
     }
+
+    OptionsToolBar.initShortcuts(optionsToolBar, forDialog);
 };
 
 /**
@@ -477,13 +467,13 @@ EAction.prototype.hideUiOptions = function(saveToSettings) {
 
     // automatically reset icon of current action from toolbar:
     if (!isNull(this.getGuiAction()) &&
-            this.getGuiAction().getGroup() !== "snaps" &&
-            this.getGuiAction().getGroup() !== "snaprestrictions") {
+        this.getGuiAction().getGroup() !== "snaps" &&
+        this.getGuiAction().getGroup() !== "snaprestrictions") {
 
         if (!this.getGuiAction().icon.isNull()) {
             var iconLabel = optionsToolBar.findChild("Icon");
             if (!isNull(iconLabel)) {
-                OptionsToolBar.setIcon("scripts/Reset/Reset.svg");
+                OptionsToolBar.setIcon(autoPath("scripts/Reset/Reset.svg"));
                 iconLabel.toolTip = qsTr("Active Tool:") + " " + qsTr("None");
             }
         }
@@ -493,7 +483,8 @@ EAction.prototype.hideUiOptions = function(saveToSettings) {
     var i;
     while (this.optionWidgetActions.length>0) {
         var a = this.optionWidgetActions.pop();
-        if (!isNull(optionsToolBar)) {
+        // QButtonGroup objects are not actions that can be removed but need to be destroyed:
+        if (!isNull(optionsToolBar) && isQAction(a)) {
             optionsToolBar.removeAction(a);
         }
         destr(a);
@@ -615,7 +606,7 @@ EAction.prototype.showDialog = function() {
     }
 
     this.dialog = WidgetFactory.createDialog(this.includeBasePath, this.dialogUiFile, EAction.getMainWindow());
-    this.initUiOptions(false, this.dialog);
+    this.initUiOptions(false, this.dialog, true);
     WidgetFactory.restoreState(this.dialog, this.settingsGroup, this);
     var title = this.getToolTitle();
     if (title.indexOf("\t")!==-1) {
@@ -667,7 +658,7 @@ EAction.prototype.showDialog = function() {
         noSyncWidgets[i].setProperty("Loaded", false);
     }
 
-    destr(this.dialog);
+    destrDialog(this.dialog);
     this.dialog = undefined;
 
 //    var view = EAction.getGraphicsView();
@@ -721,26 +712,6 @@ EAction.prototype.escapeEvent = function() {
  * Called when the user presses a key. By default, the event is ignored.
  */
 EAction.prototype.keyPressEvent = function(event) {
-    if (isNull(event)) {
-        return;
-    }
-
-    // prevent focus shift when entering keycode (e.g. "D2"):
-    var appWin = EAction.getMainWindow();
-    if (appWin.getKeyLog().length===0) {
-        if ((event.key() >= Qt.Key_0.valueOf() && event.key() <= Qt.Key_9.valueOf()) || event.key() === Qt.Key_Period.valueOf()) {
-            // number or dot entered:
-            // give focus to first input widget in options tool bar and set text to number entered:
-            var w = OptionsToolBar.getFirstInputWidget();
-            if (!isNull(w)) {
-                w.setFocus(Qt.OtherFocusReason);
-                w.text = String.fromCharCode(event.key());
-                event.accept();
-                return;
-            }
-        }
-    }
-
     event.ignore();
 };
 
@@ -762,7 +733,7 @@ EAction.prototype.setCrosshairCursor = function() {
             EAction.crossCursor = new QCursor(Qt.CrossCursor);
         }
         else {
-            var bitmap, mask
+            var bitmap, mask;
             if (RSettings.getDevicePixelRatio()===2 && RS.getSystemId()!=="osx") {
                 bitmap = new QBitmap(EAction.includeBasePath + "/CrosshairCursor@2x.png", "PNG");
                 mask = new QBitmap(EAction.includeBasePath + "/CrosshairCursorMask@2x.png", "PNG");
@@ -974,6 +945,15 @@ EAction.getGraphicsView = function() {
     return di.getLastKnownViewWithFocus();
 };
 
+EAction.getGraphicsViewWidget = function() {
+    var view = EAction.getGraphicsView();
+    if (isNull(view)) {
+        return undefined;
+    }
+
+    return view.getWidget();
+};
+
 /**
  * \return the existing menu with the given object name or, if no such menu
  * exists, a new menu with the given title and the given object name.
@@ -1667,8 +1647,9 @@ EAction.getScales = function(unit) {
 };
 
 /**
- * Called by updatePreview. Implementations must return an ROperation subclass
- * object for the operation that should be previewed.
+ * Called by updatePreview and applyOperation.
+ * Implementations must return an ROperation subclass
+ * object for the operation that should be previewed or applied.
  */
 EAction.prototype.getOperation = function(preview) {
     return undefined;
@@ -2025,6 +2006,14 @@ EAction.prototype.getToolTitle = function() {
     return guiAction.text.replace("&", "");
 };
 
+EAction.prototype.getClassName = function() {
+    var guiAction = this.getGuiAction();
+    if (isNull(guiAction)) {
+        return "";
+    }
+    return guiAction.getScriptClass();
+};
+
 EAction.disableCoordinateWidget = function() {
     EAction.enableCoordinateWidget(false);
 };
@@ -2050,7 +2039,7 @@ EAction.enableCoordinateWidget = function(enable) {
 
 /**
  * \return ID of entity closest to the mouse cursor. No handling of ambiguous results.
- * \param event RRInputEvent
+ * \param event RInputEvent
  * \param range Cursor range in pixels
  */
 EAction.getEntityIdUnderCursor = function(di, event, range, selectable) {
@@ -2074,7 +2063,7 @@ EAction.getEntityIdUnderCursor = function(di, event, range, selectable) {
 
 /**
  * \return Array of entity IDs of entities closest to the mouse cursor.
- * \param event RRInputEvent
+ * \param event RInputEvent
  * \param range Cursor range in pixels
  */
 EAction.getEntityIdsUnderCursor = function(di, event, range, selectable) {
@@ -2156,7 +2145,7 @@ EAction.getEntityId = function(di, action, event, preview, selectable) {
     // multiple entities under cursor, offer context menu:
     var ret = RObject.INVALID_ID;
     var doc = di.getDocument();
-    var menu = new QMenu(EAction.getGraphicsView());
+    var menu = new QMenu(EAction.getGraphicsViewWidget());
     menu.objectName = "EntityContextMenu";
 
     // reacts to hovering and clicking of context menu items:
@@ -2308,10 +2297,18 @@ EAction.warnNotLineArcCircleEllipseSplinePolyline = function() {
     EAction.handleUserWarning(qsTr("Entity is not a line, arc, circle, ellipse, spline or polyline."));
 };
 
+EAction.warnNotCircleEllipseSplinePolyline = function() {
+    EAction.handleUserWarning(qsTr("Entity is not a circle, ellipse, spline or polyline."));
+};
+
 EAction.warnNotPolyline = function() {
     EAction.handleUserWarning(qsTr("Entity is not a polyline."));
 };
 
+EAction.warnNotClosedPolyline = function() {
+    EAction.handleUserWarning(qsTr("Entity is not a closed polyline."));
+};
+
 EAction.warnNotSplineWithFitPoints = function() {
     EAction.handleUserWarning(qsTr("Entity is not a spline with fit points."));
 };
