@@ -48,6 +48,7 @@ Print.defaultPrinter = undefined;
 
 Print.getDefaultPrinter = function() {
     if (isNull(Print.defaultPrinter)) {
+        // TODO: this can be extremely slow if the default printer is a network printer:
         Print.defaultPrinter = new QPrinter();
     }
     return Print.defaultPrinter;
@@ -115,17 +116,18 @@ Print.prototype.createPrinter = function(pdfFile, printerName, pdfVersion) {
         }
     }
 
-    var paperSizeEnum = Print.getPaperSizeEnum(this.document);
-    if (paperSizeEnum!==QPrinter.Custom) {
-        printer.setPaperSize(paperSizeEnum);
+    // always use custom page size to work around Qt page size limitations:
+    var paperSizeMM = Print.getPaperSizeMM(this.document);
+    if (RSettings.getQtVersion() >= 0x060000) {
+        printer.setPageSize(new QPageSize(paperSizeMM, QPageSize.Millimeter));
+        printer.setFullPage(true);
+        printer.setPageOrientation(Print.getPageOrientationEnum(this.document));
     }
     else {
-        //printer.setPaperSize(QPrinter.Custom);
-        var paperSizeMM = Print.getPaperSizeMM(this.document);
         printer.setPaperSize(paperSizeMM, QPrinter.Millimeter);
+        printer.setFullPage(true);
+        printer.setOrientation(Print.getPageOrientationEnum(this.document));
     }
-    printer.setFullPage(true);
-    printer.setOrientation(Print.getPageOrientationEnum(this.document));
 
     var colorMode = Print.getColorMode(this.document);
     if (colorMode == RGraphicsView.FullColor) {
@@ -144,7 +146,7 @@ Print.prototype.createPrinter = function(pdfFile, printerName, pdfVersion) {
         if (RSettings.isQt(5)) {
             Print.printDialog.rejected.connect(function() { Print.cancel = true; });
             Print.printDialog.exec();
-            Print.printDialog.destroy();
+            destrDialog(Print.printDialog);
             EAction.activateMainWindow();
         }
         else {
@@ -155,7 +157,7 @@ Print.prototype.createPrinter = function(pdfFile, printerName, pdfVersion) {
                             Print.cancel = false;
                             Print.printDialog.close();
                             if (RS.getSystemId()==="osx") {
-                                Print.printDialog.destroy();
+                                destrDialog(Print.printDialog);
                                 EAction.activateMainWindow();
                             }
                         });
@@ -165,7 +167,7 @@ Print.prototype.createPrinter = function(pdfFile, printerName, pdfVersion) {
                             Print.cancel = true;
                             Print.printDialog.close();
                             if (RS.getSystemId()==="osx") {
-                                Print.printDialog.destroy();
+                                destrDialog(Print.printDialog);
                                 EAction.activateMainWindow();
                             }
                         });
@@ -183,7 +185,7 @@ Print.prototype.createPrinter = function(pdfFile, printerName, pdfVersion) {
         }
 
         if (Print.cancel===true) {
-            printer.destroy();
+            destr(printer);
             return undefined;
         }
     }
@@ -213,14 +215,19 @@ Print.prototype.print = function(pdfFile, printerName, pdfVersion) {
 
     var painter = new QPainter();
     if (!painter.begin(printer)) {
-        printer.destroy();
+        destr(printer);
         return false;
     }
 
-    this.printCurrentBlock(printer, painter);
+    //for (var i=1; i<=printer.copyCount(); i++) {
+        //if (i>1) {
+        //    printer.newPage();
+        //}
+        this.printCurrentBlock(printer, painter);
+    //}
 
     painter.end();
-    printer.destroy();
+    destr(printer);
 
     return true;
 };
@@ -262,9 +269,17 @@ Print.prototype.printCurrentBlock = function(printer, painter) {
     var heightInMM = printer.paperRect(QPrinter.Millimeter).height();
 
     // factor from mm to printer unit:
+    var paperRect;
+    if (RSettings.getQtVersion() >= 0x060000) {
+        paperRect = printer.pageLayout().fullRectPixels(printer.resolution());
+    }
+    else {
+        paperRect = printer.paperRect();
+    }
+
     var printerFactor = new RVector(
-        printer.paperRect().width() / widthInMM,
-        printer.paperRect().height() / heightInMM
+        paperRect.width() / widthInMM,
+        paperRect.height() / heightInMM
     );
 
     // printer calibration:
@@ -286,8 +301,8 @@ Print.prototype.printCurrentBlock = function(printer, painter) {
     var previousPixelSizeHint = this.scene.getPixelSizeHint();
 
     var widthInDrawingUnits = RUnit.convert(widthInMM, RS.Millimeter, this.document.getUnit());
-    if (printer.paperRect().width()>0) {
-        var pixelSizeHint = 1.0/printer.paperRect().width()*widthInDrawingUnits;
+    if (paperRect.width()>0) {
+        var pixelSizeHint = 1.0/paperRect.width()*widthInDrawingUnits;
         pixelSizeHint = pixelSizeHint / scale;
         this.scene.setPixelSizeHint(pixelSizeHint);
     }
@@ -295,8 +310,24 @@ Print.prototype.printCurrentBlock = function(printer, painter) {
     // iterate through all pages and print the appropriate area
     var firstPage = true;
 
+    var fromPage = printer.fromPage();
+    var toPage = printer.toPage();
+
     var pages = Print.getPages(this.document);
     for (var i = 0; i < pages.length; ++i) {
+
+        if (fromPage!==0) {
+            if (i+1<fromPage) {
+                continue;
+            }
+        }
+
+        if (toPage!==0) {
+            if (i+1>toPage) {
+                continue;
+            }
+        }
+
         // if this is not the first page, add new page:
         if (!firstPage) {
             printer.newPage();
@@ -310,7 +341,7 @@ Print.prototype.printCurrentBlock = function(printer, painter) {
         if (!qclr.equals(new QColor(Qt.white))) {
             painter.setWorldTransform(new QTransform());
             painter.setBackground(new QBrush(qclr, Qt.SolidPattern));
-            painter.eraseRect(printer.paperRect());
+            painter.eraseRect(paperRect);
         }
 
         // paper size in mm:
@@ -402,7 +433,7 @@ Print.prototype.printPage = function(painter, rect) {
         )
     );
 
-    this.view.paintOverlay(painter);
+    this.view.paintOverlay();
 };
 
 /**
@@ -431,12 +462,25 @@ Print.getPaperBox = function(document) {
 
 /**
  * Auto fit drawing to page size.
+ * \param ori: True: auto set page orientation
  */
-Print.autoFitDrawing = function(di) {
+Print.autoFitDrawing = function(di, ori) {
+    if (isNull(ori)) {
+        ori = false;
+    }
+
     var document = di.getDocument();
     // drawing bounding box in drawing units:
     var bBox = document.getBoundingBox(true, true);
     //qDebug("bb: ", bBox);
+    if (ori) {
+        if (bBox.getWidth()>bBox.getHeight()) {
+            Print.setPageOrientationEnum(di, RS.Landscape);
+        }
+        else {
+            Print.setPageOrientationEnum(di, RS.Portrait);
+        }
+    }
     Print.autoFitBox(di, bBox);
     Print.centerBox(di, bBox);
 };
@@ -530,7 +574,14 @@ Print.centerBox = function(di, bBox) {
  * \param painter QPainter object if we are printing, RPainterPath for print preview.
  */
 Print.drawCropMarks = function(document, painter, border, printing) {
-    var isPainter = isFunction(painter.drawLinesF);
+    var isPainter;
+
+    if (RSettings.getQtVersion()>=0x060000) {
+        isPainter = isFunction(painter.drawLines);
+    }
+    else {
+        isPainter = isFunction(painter.drawLinesF);
+    }
 
     var clipping = false;
     if (isPainter) {
@@ -569,10 +620,15 @@ Print.drawCropMarks = function(document, painter, border, printing) {
         for (var k=0; k<lines.length; ++k) {
             lines[k].translate(-offset.x, -offset.y);
         }
-        painter.drawLinesF(lines);
+        if (RSettings.getQtVersion()>=0x060000) {
+            painter.drawLines(lines);
+        }
+        else {
+            painter.drawLinesF(lines);
+        }
     }
 
-    // preview:
+    // preview (painter path):
     else {
         for (var i=0; i<lines.length; ++i) {
             painter.moveTo(new RVector(lines[i].x1(), lines[i].y1()));
@@ -790,7 +846,7 @@ Print.getPages = function(document) {
     var w;
     var h;
     var paperSizeMM = Print.getPaperSizeMM(document);
-    if (Print.getPageOrientationEnum(document) === QPrinter.Portrait) {
+    if (Print.getPageOrientationEnum(document) === RS.Portrait) {
         w = paperSizeMM.width();
         h = paperSizeMM.height();
     } else {
@@ -1050,7 +1106,11 @@ Print.getGlueMarginLeft = function(document) {
 
 Print.getDefaultPrintMarginLeft = function(document, paperUnit) {
     var pageRect = Print.getDefaultPageRect(document, paperUnit);
-    return pageRect.left().toFixed(4);
+    var ret = parseFloat(pageRect.left().toFixed(4));
+    if (!isNumber(ret)) {
+        return 0.0;
+    }
+    return ret;
 };
 
 Print.getGlueMarginTop = function(document) {
@@ -1059,7 +1119,11 @@ Print.getGlueMarginTop = function(document) {
 
 Print.getDefaultPrintMarginTop = function(document, paperUnit) {
     var pageRect = Print.getDefaultPageRect(document, paperUnit);
-    return pageRect.top().toFixed(4);
+    var ret = parseFloat(pageRect.top().toFixed(4));
+    if (!isNumber(ret)) {
+        return 0.0;
+    }
+    return ret;
 };
 
 Print.getGlueMarginRight = function(document) {
@@ -1069,7 +1133,11 @@ Print.getGlueMarginRight = function(document) {
 Print.getDefaultPrintMarginRight = function(document, paperUnit) {
     var paperRect = Print.getDefaultPaperRect(document, paperUnit);
     var pageRect = Print.getDefaultPageRect(document, paperUnit);
-    return (paperRect.right() - pageRect.right()).toFixed(4);
+    var ret = parseFloat((paperRect.right() - pageRect.right()).toFixed(4));
+    if (!isNumber(ret)) {
+        return 0.0;
+    }
+    return ret;
 };
 
 Print.getGlueMarginBottom = function(document) {
@@ -1079,7 +1147,11 @@ Print.getGlueMarginBottom = function(document) {
 Print.getDefaultPrintMarginBottom = function(document, paperUnit) {
     var paperRect = Print.getDefaultPaperRect(document, paperUnit);
     var pageRect = Print.getDefaultPageRect(document, paperUnit);
-    return (paperRect.bottom() - pageRect.bottom()).toFixed(4);
+    var ret = parseFloat((paperRect.bottom() - pageRect.bottom()).toFixed(4));
+    if (!isNumber(ret)) {
+        return 0.0;
+    }
+    return ret;
 };
 
 Print.getOffset = function(document) {
@@ -1110,11 +1182,53 @@ Print.getPaperSizeMM = function(document) {
  * or QPrinter.
  */
 Print.getDefaultPaperSizeMM = function() {
-    var defaultPaperSizeMM = Print.getDefaultPrinter().paperSize(QPrinter.Millimeter);
+    var defaultPrinter = Print.getDefaultPrinter();
 
-    var dwMM = defaultPaperSizeMM.width();
-    var dhMM = defaultPaperSizeMM.height();
+    var dwMM;
+    var dhMM;
 
+    if (RSettings.getQtVersion() >= 0x060000) {
+        var defaultPaperSize = defaultPrinter.pageLayout().pageSize();
+
+        // paper size in appropriate unit:
+        var size = defaultPaperSize.definitionSize();
+        var wUnit = size.width();
+        var hUnit = size.height();
+
+        // unit of paper size:
+        var unit = defaultPaperSize.definitionUnits();
+
+        // convert unit to mm:
+        var factor = 1.0;
+        switch (unit) {
+        case QPageSize.Point:
+            factor = 72 / 25.4;
+            break;
+        case QPageSize.Inch:
+            factor = 25.4;
+            break;
+        case QPageSize.Pica:
+            factor = 6 / 25.4;
+            break;
+        case QPageSize.Didot:
+            factor = 1 / 0.365;
+            break;
+        case QPageSize.Cicero:
+            factor = 1 / 4.5;
+            break;
+        default:
+        case QPageSize.Millimeter:
+            factor = 1.0;
+            break;
+        }
+        dwMM = wUnit * factor;
+        dhMM = hUnit * factor;
+    }
+    else {
+        var defaultPaperSizeMM = defaultPrinter.paperSize(QPrinter.Millimeter);
+        dwMM = defaultPaperSizeMM.width();
+        dhMM = defaultPaperSizeMM.height();
+    }
     // get w / h in paper unit from settings:
     var dw = RUnit.convert(dwMM, RS.Millimeter, Print.getDefaultPaperUnit());
     var dh = RUnit.convert(dhMM, RS.Millimeter, Print.getDefaultPaperUnit());
@@ -1199,7 +1313,7 @@ Print.getPaperSizeEnum = function(document) {
         }
     }
 
-    return QPrinter.Custom;
+    return undefined;
 };
 
 /**
@@ -1313,10 +1427,10 @@ Print.getDefaultPaperSizeName = function(document) {
 Print.getPageOrientationEnum = function(document) {
     var pageOrientationString = Print.getPageOrientationString(document);
     if (pageOrientationString==="Landscape") {
-        return QPrinter.Landscape;
+        return RS.Landscape;
     }
     else {
-        return QPrinter.Portrait;
+        return RS.Portrait;
     }
 };
 
@@ -1329,7 +1443,7 @@ Print.setPageOrientationString = function(di, pageOrientation) {
 };
 
 Print.setPageOrientationEnum = function(di, pageOrientation) {
-    if (pageOrientation.valueOf()===QPrinter.Landscape.valueOf()) {
+    if (pageOrientation===RS.Landscape) {
         Print.setPageOrientationString(di, "Landscape");
     }
     else {
