@@ -3531,13 +3531,21 @@ function createValidator(rx, parent) {
 }
 
 function parseXml(fileName, handler) {
-    var fi = new QFileInfo(fileName);
-    var file = new QFile(fi.absoluteFilePath());
-    var xmlReader = new QXmlSimpleReader();
-    var source = new QXmlInputSource(file);
-    xmlReader.setContentHandler(handler);
-    var ret = xmlReader.parse(source, false);
-    file.close();
+    // Qt 6: use JS implementation:
+    if (RSettings.getQtVersion()>=0x060000) {
+        var fi = new QFileInfo(fileName);
+        var file = new QFile(fi.absoluteFilePath());
+        var xmlReader = new QXmlSimpleReader();
+        var source = new QXmlInputSource(file);
+        xmlReader.setContentHandler(handler);
+        var ret = xmlReader.parse(source, false);
+        file.close();
+    }
+
+    // Qt 5: implementation in RScriptHandlerEcma:
+    else {
+        parseXmlQt5(fileName, handler);
+    }
 }
 
 // fix QPlainTextEdit API for Qt 5:
