@@ -243,7 +243,7 @@
         <translation>Blok</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+99"/>
+        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+102"/>
         <location line="+1"/>
         <location line="+1"/>
         <location filename="../src/core/RViewportEntity.cpp" line="+80"/>
@@ -253,7 +253,7 @@
         <translation>Positie</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlock.cpp" line="+69"/>
+        <location filename="../src/core/RBlock.cpp" line="+75"/>
         <source>Pixel Unit</source>
         <translation>Pixeleenheid</translation>
     </message>
@@ -322,10 +322,20 @@
         <translation>Eigendom van Referentie</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-6"/>
+        <location line="+1"/>
+        <source>External reference</source>
+        <translation>Externe referentie</translation>
+    </message>
+    <message>
+        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-7"/>
         <source>Referenced Block</source>
         <translation>Gerefereerde blok</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>External Reference</source>
+        <translation>Externe referentie</translation>
+    </message>
     <message>
         <location line="+4"/>
         <location line="+1"/>
@@ -623,7 +633,7 @@
         <translation>Laag ID</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlock.cpp" line="-7"/>
+        <location filename="../src/core/RBlock.cpp" line="-8"/>
         <location filename="../src/core/RLayer.cpp" line="-8"/>
         <location filename="../src/core/RLayerState.cpp" line="+46"/>
         <location filename="../src/core/RLayout.cpp" line="-24"/>
@@ -711,7 +721,7 @@
         <translation>Max afmetingen</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlockReferenceData.cpp" line="+886"/>
+        <location filename="../src/core/RBlockReferenceData.cpp" line="+920"/>
         <source>Circular (recursive) block referencing detected:</source>
         <translation>Circulaire (recursieve) blokreferenties gedetecteerd:</translation>
     </message>
@@ -758,7 +768,7 @@
     <message>
         <location line="+1"/>
         <source>Extension line offset</source>
-        <translation>Hulplijn afzet</translation>
+        <translation>Extensielijnafzet</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -818,7 +828,7 @@
     <message>
         <location line="+1"/>
         <source>Architectur tick</source>
-        <translation>Architectur tick</translation>
+        <translation>Architecturale markering</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -1055,6 +1065,21 @@
         <source>Fenceline 2</source>
         <translation>Grens vierkant</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Point 1</source>
+        <translation>Punt 1</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Point 2</source>
+        <translation>Punt 2</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Plant</source>
+        <translation>Installatie</translation>
+    </message>
     <message>
         <location line="+2"/>
         <source>Water</source>
