@@ -243,7 +243,7 @@
         <translation>Block</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+99"/>
+        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+102"/>
         <location line="+1"/>
         <location line="+1"/>
         <location filename="../src/core/RViewportEntity.cpp" line="+80"/>
@@ -253,7 +253,7 @@
         <translation>Position</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlock.cpp" line="+69"/>
+        <location filename="../src/core/RBlock.cpp" line="+75"/>
         <source>Pixel Unit</source>
         <translation>Pixel-enhet</translation>
     </message>
@@ -322,10 +322,20 @@
         <translation>Ägs av Referens</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-6"/>
+        <location line="+1"/>
+        <source>External reference</source>
+        <translation>Extern referens</translation>
+    </message>
+    <message>
+        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-7"/>
         <source>Referenced Block</source>
         <translation>Block som är referenser</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>External Reference</source>
+        <translation>Extern referens</translation>
+    </message>
     <message>
         <location line="+4"/>
         <location line="+1"/>
@@ -623,7 +633,7 @@
         <translation>Lager-ID</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlock.cpp" line="-7"/>
+        <location filename="../src/core/RBlock.cpp" line="-8"/>
         <location filename="../src/core/RLayer.cpp" line="-8"/>
         <location filename="../src/core/RLayerState.cpp" line="+46"/>
         <location filename="../src/core/RLayout.cpp" line="-24"/>
@@ -711,7 +721,7 @@
         <translation>Max utsträckning</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlockReferenceData.cpp" line="+886"/>
+        <location filename="../src/core/RBlockReferenceData.cpp" line="+920"/>
         <source>Circular (recursive) block referencing detected:</source>
         <translation>Detekterat cirkulärt beroende mellan block:</translation>
     </message>
@@ -1055,6 +1065,21 @@
         <source>Fenceline 2</source>
         <translation>Gränslinje 2</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Point 1</source>
+        <translation>Punkt 1</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Point 2</source>
+        <translation>Punkt 2</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Plant</source>
+        <translation>Anläggning</translation>
+    </message>
     <message>
         <location line="+2"/>
         <source>Water</source>
