@@ -219,7 +219,7 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Middle</source>
-        <translation type="unfinished">null</translation>
+        <translation>中點</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -237,13 +237,13 @@
         <location line="+1"/>
         <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
         <source>End Angle</source>
-        <translation type="unfinished">null</translation>
+        <translation>結束角度</translation>
     </message>
     <message>
         <location line="+1"/>
         <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
         <source>Reversed</source>
-        <translation type="unfinished">null</translation>
+        <translation>反轉</translation>
     </message>
     <message>
         <location line="+2"/>
@@ -281,7 +281,7 @@
     <message>
         <location line="+1"/>
         <source>Sweep Angle</source>
-        <translation type="unfinished">null</translation>
+        <translation>掃掠角度</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -308,18 +308,18 @@
     <message>
         <location line="+1"/>
         <source>Prompt</source>
-        <translation type="unfinished">null</translation>
+        <translation>提示</translation>
     </message>
     <message>
         <location line="-3"/>
         <location filename="../src/entity/RAttributeEntity.cpp" line="+1"/>
         <source>Invisible</source>
-        <translation type="unfinished">null</translation>
+        <translation>不可見</translation>
     </message>
     <message>
         <location filename="../src/entity/RCircleEntity.cpp" line="-2"/>
         <source>Circumference</source>
-        <translation type="unfinished">null</translation>
+        <translation>圓周</translation>
     </message>
     <message>
         <location filename="../src/entity/RDimLinearEntity.cpp" line="-10"/>
@@ -333,49 +333,49 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Extension Point 1</source>
-        <translation type="unfinished">null</translation>
+        <translation>延伸點 1</translation>
     </message>
     <message>
         <location line="+2"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Extension Point 2</source>
-        <translation type="unfinished">null</translation>
+        <translation>延伸點 2</translation>
     </message>
     <message>
         <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-14"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Line 1 Start</source>
-        <translation type="unfinished">null</translation>
+        <translation>線段 1 起點</translation>
     </message>
     <message>
         <location filename="../src/entity/RDimAngularEntity.cpp" line="-10"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Line 1 End</source>
-        <translation type="unfinished">null</translation>
+        <translation>線段 1 終點</translation>
     </message>
     <message>
         <location filename="../src/entity/RDimAngular2LEntity.cpp" line="+10"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Line 2 Start</source>
-        <translation type="unfinished">null</translation>
+        <translation>線段 2 起點</translation>
     </message>
     <message>
         <location filename="../src/entity/RDimAngularEntity.cpp" line="+2"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Line 2 End</source>
-        <translation type="unfinished">null</translation>
+        <translation>線段 2 終點</translation>
     </message>
     <message>
         <location line="+2"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Dimension Arc</source>
-        <translation type="unfinished">null</translation>
+        <translation>標註弧</translation>
     </message>
     <message>
         <location filename="../src/entity/RDimDiametricEntity.cpp" line="-6"/>
@@ -385,14 +385,14 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Chord Point</source>
-        <translation type="unfinished">null</translation>
+        <translation>弦點</translation>
     </message>
     <message>
         <location line="+2"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Far Chord Point</source>
-        <translation type="unfinished">null</translation>
+        <translation>遠弦點</translation>
     </message>
     <message>
         <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-10"/>
@@ -406,26 +406,26 @@
     <message>
         <location line="+2"/>
         <source>Ordinate</source>
-        <translation type="unfinished">null</translation>
+        <translation>縱座標</translation>
     </message>
     <message>
         <location line="+1"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Defining Point</source>
-        <translation type="unfinished">null</translation>
+        <translation>定義點</translation>
     </message>
     <message>
         <location line="+1"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Leader End Point</source>
-        <translation type="unfinished">null</translation>
+        <translation>引線終點</translation>
     </message>
     <message>
         <location filename="../src/entity/RDimRotatedEntity.cpp" line="+172"/>
         <source>Dimension Angle</source>
-        <translation type="unfinished">null</translation>
+        <translation>標註角度</translation>
     </message>
     <message>
         <location filename="../src/entity/RDimensionEntity.cpp" line="-8"/>
@@ -453,7 +453,7 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Definition Point</source>
-        <translation type="unfinished">null</translation>
+        <translation>定義點</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -465,22 +465,22 @@
     <message>
         <location line="+3"/>
         <source>Text Rotation</source>
-        <translation type="unfinished">文字旋轉</translation>
+        <translation>文字旋轉</translation>
     </message>
     <message>
         <location line="+3"/>
         <source>Flip First Arrow</source>
-        <translation type="unfinished">null</translation>
+        <translation>翻轉第一個箭頭</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Flip Second Arrow</source>
-        <translation type="unfinished">null</translation>
+        <translation>翻轉第二個箭頭</translation>
     </message>
     <message>
         <location line="+2"/>
         <source>Fixed Extension Line</source>
-        <translation type="unfinished">null</translation>
+        <translation>固定延伸線</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -490,12 +490,12 @@
     <message>
         <location line="+8"/>
         <source>Auto Label</source>
-        <translation type="unfinished">null</translation>
+        <translation>自動標籤</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Measured Value</source>
-        <translation type="unfinished">null</translation>
+        <translation>測量值</translation>
     </message>
     <message>
         <location filename="../src/entity/RHatchEntity.cpp" line="-3"/>
@@ -510,29 +510,29 @@
     <message>
         <location line="+1"/>
         <source>Auto Label Position</source>
-        <translation type="unfinished">null</translation>
+        <translation>自動標籤位置</translation>
     </message>
     <message>
         <location filename="../src/entity/REllipseEntity.cpp" line="-17"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Major Point</source>
-        <translation type="unfinished">null</translation>
+        <translation>主要點</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Ratio</source>
-        <translation type="unfinished">null</translation>
+        <translation>比例</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Start Parameter</source>
-        <translation type="unfinished">null</translation>
+        <translation>起始參數</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>End Parameter</source>
-        <translation type="unfinished">null</translation>
+        <translation>結束參數</translation>
     </message>
     <message>
         <location line="+5"/>
@@ -542,7 +542,7 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Start Point</source>
-        <translation type="unfinished">null</translation>
+        <translation>起點</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -552,7 +552,7 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>End Point</source>
-        <translation type="unfinished">null</translation>
+        <translation>終點</translation>
     </message>
     <message>
         <location filename="../src/entity/RHatchEntity.cpp" line="-7"/>
@@ -562,12 +562,12 @@
     <message>
         <location line="+1"/>
         <source>Winding</source>
-        <translation type="unfinished">繞線</translation>
+        <translation>繞線</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Alpha</source>
-        <translation type="unfinished">null</translation>
+        <translation>透明度</translation>
     </message>
     <message>
         <location line="+2"/>
@@ -585,7 +585,7 @@
     <message>
         <location line="+1"/>
         <source>From Entity</source>
-        <translation type="unfinished">null</translation>
+        <translation>從實體</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -616,17 +616,17 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Vertex</source>
-        <translation type="unfinished">null</translation>
+        <translation>頂點</translation>
     </message>
     <message>
         <location line="+201"/>
         <source>Yes</source>
-        <translation type="unfinished">null</translation>
+        <translation>是</translation>
     </message>
     <message>
         <location line="+0"/>
         <source>No</source>
-        <translation type="unfinished">null</translation>
+        <translation>否</translation>
     </message>
     <message>
         <location filename="../src/entity/RImageEntity.cpp" line="-18"/>
@@ -647,13 +647,13 @@
         <location line="+2"/>
         <location line="+1"/>
         <source>U</source>
-        <translation type="unfinished">null</translation>
+        <translation>U</translation>
     </message>
     <message>
         <location line="+2"/>
         <location line="+1"/>
         <source>V</source>
-        <translation type="unfinished">null</translation>
+        <translation>V</translation>
     </message>
     <message>
         <location line="+2"/>
@@ -688,17 +688,17 @@
     <message>
         <location line="+1"/>
         <source>Spline</source>
-        <translation type="unfinished">null</translation>
+        <translation>曲線</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Arrow Block</source>
-        <translation type="unfinished">null</translation>
+        <translation>箭頭圖塊</translation>
     </message>
     <message>
         <location filename="../src/entity/RPolylineEntity.cpp" line="-9"/>
         <source>Polyline Pattern</source>
-        <translation type="unfinished">null</translation>
+        <translation>聚合線樣式</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -709,27 +709,27 @@
         <location line="+4"/>
         <location filename="../src/entity/RWipeoutEntity.cpp" line="+0"/>
         <source>Bulge</source>
-        <translation type="unfinished">null</translation>
+        <translation>凸度</translation>
     </message>
     <message>
         <location line="+3"/>
         <source>Start Width</source>
-        <translation type="unfinished">null</translation>
+        <translation>起始寬度</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>End Width</source>
-        <translation type="unfinished">null</translation>
+        <translation>結束寬度</translation>
     </message>
     <message>
         <location line="+2"/>
         <source>Global Width</source>
-        <translation type="unfinished">null</translation>
+        <translation>全域寬度</translation>
     </message>
     <message>
         <location line="+2"/>
         <source>Orientation</source>
-        <translation type="unfinished">null</translation>
+        <translation>方向</translation>
     </message>
     <message>
         <location line="+9"/>
@@ -739,30 +739,30 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Size</source>
-        <translation type="unfinished">null</translation>
+        <translation>大小</translation>
     </message>
     <message>
         <location line="-2"/>
         <location filename="../src/entity/RWipeoutEntity.cpp" line="-2"/>
         <source>Base Angle</source>
-        <translation type="unfinished">null</translation>
+        <translation>基礎角度</translation>
     </message>
     <message>
         <location line="+1"/>
         <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
         <source>Size 1</source>
-        <translation type="unfinished">null</translation>
+        <translation>尺寸 1</translation>
     </message>
     <message>
         <location line="+1"/>
         <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
         <source>Size 2</source>
-        <translation type="unfinished">null</translation>
+        <translation>尺寸 2</translation>
     </message>
     <message>
         <location line="+2"/>
         <source>Global Z</source>
-        <translation type="unfinished">null</translation>
+        <translation>全域 Z</translation>
     </message>
     <message>
         <location filename="../src/entity/RRayEntity.cpp" line="-11"/>
@@ -772,7 +772,7 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Base Point</source>
-        <translation type="unfinished">null</translation>
+        <translation>基準點</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -782,7 +782,7 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Second Point</source>
-        <translation type="unfinished">null</translation>
+        <translation>第二點</translation>
     </message>
     <message>
         <location line="+2"/>
@@ -792,7 +792,7 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Direction Vector</source>
-        <translation type="unfinished">null</translation>
+        <translation>方向向量</translation>
     </message>
     <message>
         <location line="+3"/>
@@ -811,7 +811,7 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Point 1</source>
-        <translation type="unfinished">null</translation>
+        <translation>點 1</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -824,7 +824,7 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Point 2</source>
-        <translation type="unfinished">null</translation>
+        <translation>點 2</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -837,7 +837,7 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Point 3</source>
-        <translation type="unfinished">null</translation>
+        <translation>點 3</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -850,36 +850,36 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Point 4</source>
-        <translation type="unfinished">null</translation>
+        <translation>點 4</translation>
     </message>
     <message>
         <location filename="../src/entity/RSplineEntity.cpp" line="-12"/>
         <source>Closed Periodic</source>
-        <translation type="unfinished">null</translation>
+        <translation>封閉周期</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Degree</source>
-        <translation type="unfinished">null</translation>
+        <translation>度</translation>
     </message>
     <message>
         <location line="+2"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Control Point</source>
-        <translation type="unfinished">null</translation>
+        <translation>控制點</translation>
     </message>
     <message>
         <location line="+1"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Fit Point</source>
-        <translation type="unfinished">null</translation>
+        <translation>擬合點</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Knot Vector</source>
-        <translation type="unfinished">null</translation>
+        <translation>節點向量</translation>
     </message>
     <message>
         <location line="+0"/>
@@ -889,62 +889,62 @@
     <message>
         <location line="+6"/>
         <source>Use Start Tangent</source>
-        <translation type="unfinished">null</translation>
+        <translation>使用起始切線</translation>
     </message>
     <message>
         <location line="+1"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Start Tangent</source>
-        <translation type="unfinished">null</translation>
+        <translation>起始切線</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Use End Tangent</source>
-        <translation type="unfinished">null</translation>
+        <translation>使用終點切線</translation>
     </message>
     <message>
         <location line="+1"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>End Tangent</source>
-        <translation type="unfinished">null</translation>
+        <translation>終點切線</translation>
     </message>
     <message>
         <location filename="../src/entity/RDimArcLengthEntity.cpp" line="+190"/>
         <source>Arc Symbol Type</source>
-        <translation type="unfinished">null</translation>
+        <translation>弧形符號類型</translation>
     </message>
     <message>
         <location filename="../src/entity/RToleranceEntity.cpp" line="-5"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Location</source>
-        <translation type="unfinished">null</translation>
+        <translation>位置</translation>
     </message>
     <message>
         <location line="+1"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Direction</source>
-        <translation type="unfinished">null</translation>
+        <translation>方向</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Text</source>
-        <translation type="unfinished">null</translation>
+        <translation>文字</translation>
     </message>
     <message>
         <location filename="../src/entity/RLineEntity.cpp" line="-7"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Middle Point</source>
-        <translation type="unfinished">null</translation>
+        <translation>中點</translation>
     </message>
     <message>
         <location filename="../src/entity/RWipeoutEntity.cpp" line="+2"/>
         <source>Frame</source>
-        <translation type="unfinished">框架</translation>
+        <translation>框架</translation>
     </message>
 </context>
 </TS>
